@@ -1,5 +1,6 @@
 """Classes and supporting functions to manipulate ordering columns and extract
 keyset markers from query results."""
+
 from __future__ import annotations
 
 from abc import ABC, abstractmethod
@@ -17,8 +18,8 @@ from sqlalchemy.sql.elements import _label_reference
 from sqlalchemy.sql.expression import ClauseList, ColumnElement, Label
 from sqlalchemy.sql.operators import asc_op, desc_op, nullsfirst_op, nullslast_op
 
-from .sqla import order_by_clauses
 from .constants import ORDER_COL_PREFIX
+from .sqla import order_by_clauses
 
 # TODO: user *could* collide with this!
 
@@ -60,12 +61,17 @@ class OC:
     :class:`sqlalchemy.sql.expression.ColumnElement` appearing in the ORDER BY
     clause of a query we are paging."""
 
+    element: ColumnElement
+    """The ordering column/SQL expression with ordering modifier removed."""
+
     def __init__(self, x, enable_warnings=True):
         if isinstance(x, str):
             x = column(x)
         if _get_order_direction(x) is None:
             x = asc(x)
         self.uo = x
+        self.element = _remove_order_direction(x)
+
         if enable_warnings:
             _warn_if_nullable(self.comparable_value)
         self.full_name = str(self.element)
@@ -82,11 +88,6 @@ class OC:
     def quoted_full_name(self):
         return str(self).split()[0]
 
-    @property
-    def element(self) -> ColumnElement:
-        """The ordering column/SQL expression with ordering modifier removed."""
-        return _remove_order_direction(self.uo)
-
     @property
     def comparable_value(self):
         """The ordering column/SQL expression in a form that is suitable for
@@ -235,7 +236,9 @@ def _remove_order_direction(ce: ColumnElement) -> ColumnElement:
                 "modifier; but sqlakeyset does not support order columns "
                 "with nulls. YOUR RESULTS WILL BE WRONG. See the "
                 "Limitations section of the sqlakeyset README for more "
-                "information."
+                "information.",
+                stacklevel=7,
+                # ^ 7 makes the warning reference the user's calling code
             )
         if mod in _ORDER_MODIFIERS:
             x._copy_internals()
